﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace Drawing
{
    public partial class MainWindow : Form
    {
        public MainWindow()
        {
            InitializeComponent();
            pictureBox_SizeChanged (null, null);
            comboBox.SelectedIndex = 0;
        }

        private void pictureBox_SizeChanged (object sender, EventArgs e)
        {
            int w = pictureBox.Width;
            int h = pictureBox.Height;

            if (pictureBox.Image != null)
            {
                if (w < pictureBox.Image.Width)
                    w = pictureBox.Image.Width;
                if (h < pictureBox.Image.Height)
                    h = pictureBox.Image.Height;
            }

            Bitmap bitmap = new Bitmap (w, h);

            Graphics g = Graphics.FromImage (bitmap);

            Brush b = new SolidBrush (Color.White);
            g.FillRectangle (b, 0, 0, w, h);

            if (pictureBox.Image != null)
               g.DrawImage (pictureBox.Image, 0, 0);

            pictureBox.Image = bitmap;
        }

        private int X0, Y0;
        private bool down = false;
        private Bitmap save = null;

        private void pictureBox_MouseDown(object sender, MouseEventArgs e)
        {
           X0 = e.X;
           Y0 = e.Y;
           down = true;
           save = new Bitmap(pictureBox.Image);
        }

        private void pictureBox_MouseMove(object sender, MouseEventArgs e)
        {
            if (down)
            {
                Graphics g = Graphics.FromImage(pictureBox.Image);
                g.DrawImage(save, 0, 0);
                Pen p = new Pen(Color.FromArgb(128, 255, 128));
                p.Width = 1;
                
                int X1 = X0;
                int Y1 = Y0;
                int X2 = e.X;
                int Y2 = e.Y;
                if (X1 > X2) { int t = X1; X1 = X2; X2 = t; }
                if (Y1 > Y2) { int t = Y1; Y1 = Y2; Y2 = t; }

                int inx = comboBox.SelectedIndex;

                if (inx == 0)
                    g.DrawLine(p, X1, Y1, X2, Y2);
                else if (inx == 1)
                    g.DrawRectangle (p, X1, Y1, X2-X1, Y2-Y1);
                else if (inx == 2)
                   g.DrawEllipse (p, X1, Y1, X2-X1, Y2-Y1);
                
                pictureBox.Invalidate();
            }
        }

        private void pictureBox_MouseUp(object sender, MouseEventArgs e)
        {
            down = false;
            int inx = comboBox.SelectedIndex;

            Graphics g = Graphics.FromImage(pictureBox.Image);
            if (save != null)
               g.DrawImage (save, 0, 0);
            Pen p = new Pen (Color.FromArgb(255, 128, 128));
            p.Width = 3;
            
            int X1 = X0;
            int Y1 = Y0;
            int X2 = e.X;
            int Y2 = e.Y;
            if (X1 > X2) { int t = X1; X1 = X2; X2 = t; }
            if (Y1 > Y2) { int t = Y1; Y1 = Y2; Y2 = t; }

            if (inx == 0)
                g.DrawLine (p, X1, Y1, X2, Y2);
            else if (inx == 1)
                g.DrawRectangle(p, X1, Y1, X2 - X1, Y2 - Y1);
            else if (inx == 2)
                g.DrawEllipse(p, X1, Y1, X2 - X1, Y2 - Y1);

            pictureBox.Invalidate();
        }

        private void quitMenu_Click(object sender, EventArgs e)
        {
            Close ();
        }

        private void openMenu_Click(object sender, EventArgs e)
        {
            if (openDialog.ShowDialog() == DialogResult.OK)
            {
                pictureBox.Image = new Bitmap (openDialog.FileName);
                pictureBox_SizeChanged (null, null);
            }
        }
    }
}
